@@ -1,24 +1,12 @@
-from unittest import SkipTest
-
-try:
-    from unittest import mock
-except (ImportError, AttributeError):
-    import mock
+from importlib import reload
+from unittest import SkipTest, mock
 
 from freezegun import api
 from tests import utils
 
-try:
-    reload
-except NameError:
-    try:
-        from importlib import reload
-    except ImportError:
-        from imp import reload
-
 
 @mock.patch('platform.python_implementation', lambda: 'CPython')
-def test_should_not_skip_cpython():
+def test_should_not_skip_cpython() -> None:
     reload(api)
     reload(utils)
     function_mock = mock.MagicMock(__name__='function')
@@ -30,7 +18,7 @@ def test_should_not_skip_cpython():
 
 
 @mock.patch('platform.python_implementation', lambda: 'not-CPython')
-def test_should_skip_non_cpython():
+def test_should_skip_non_cpython() -> None:
     reload(api)
     reload(utils)
     function_mock = mock.MagicMock(__name__='function', skipped=False)
